#
# spec file for package python-tld
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-tld
Version:        0.13
Release:        1.2
Summary:        URL top level domain (TLD) extraction module
License:        GPL-2.0-only OR MPL-1.1 OR LGPL-2.1-or-later
URL:            https://github.com/barseghyanartur/tld
Source:         https://files.pythonhosted.org/packages/source/t/tld/tld-%{version}.tar.gz
# PATCH-FIX-OPENSUSE skip_internet_tests.patch
Patch0:         skip_internet_tests.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Faker}
BuildRequires:  %{python_module factory_boy}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This module extracts the top level domain (TLD) from the URL given.
A list of TLD names is taken from Mozillas public suffix list:
<https://publicsuffix.org/list/effective_tld_names.dat>

%prep
%autosetup -p1 -n tld-%{version}
# https://github.com/barseghyanartur/tld/issues/75

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/update-tld-names
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative update-tld-names

%postun
%python_uninstall_alternative update-tld-names

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE_GPL2.0.txt LICENSE_LGPL_2.1.txt LICENSE_MPL_1.1.txt
%python_alternative %{_bindir}/update-tld-names
%{python_sitelib}/tld
%{python_sitelib}/tld-%{version}.dist-info

%changelog
* Tue Mar  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.0:
  * Drop Python 2.7, 3.5 and 3.6 support. Minimum required version now is
    Python 3.7.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Mon Oct 17 2022 pgajdos@suse.com
- python-six is not required
* Sun Jun 20 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.12.6:
  - Move Registry class from tld.registry to tld.base.
  - Reformat code using black.
  - Log information on updated resources of the update_tld_names.
* Wed May 19 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 0.12.5:
    Release dedicated to defenders of Armenia and Artsakh (Nagorno Karabakh)
    and all the victims of Turkish and Azerbaijani aggression.
  - Fixed lower-cased `parsed_url` attributes (`SplitResult`) when getting
    tld as object (`as_object=True`).
- Update to version 0.12.4:
  - Tested against Python 3.9.
* Sun Dec 20 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 0.12.3:
  - Separate parsers for (a) public and private and (b) public only domains. This
    fixes a bug. If you want an old behaviour:
    The following code would raise exception in past.
    .. code-block:: python
    from tld import get_tld
    get_tld(
    'http://silly.cc.ua',
    search_private=False
    )
    Now it would return `ua`.
    .. code-block:: python
    get_tld(
    'http://silly.cc.ua',
    search_private=False
    )
    If you want old behavior, do as follows:
    .. code-block:: python
    from tld.utils import MozillaTLDSourceParser
    get_tld(
    'http://silly.cc.ua',
    search_private=False,
    parser_class=MozillaTLDSourceParser
    )
    Same goes for ``get_fld``, ``process_url``, ``parse_tld`` and ``is_tld``
    functions.
* Thu May 21 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 0.12.2:
  - Add mozilla license to dist.
  - Fix MyPy issues.
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sun May  3 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.12.1:
  - Correctly handling domain names ending with dot(s).
* Wed Apr 22 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.12:
  - Use Public Suffix list instead of deprecated Mozilla's MXR.
* Thu Mar 26 2020 pgajdos@suse.com
- version update to 0.11.11
  * - Minor speed-ups, reduce memory usage.
* Thu Feb  6 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.11.10:
  - Python 2.7 and 3.5 fixes.
* Thu Jan  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not use setup.py test but call pytest directly
* Tue Dec 24 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.11.9:
  - Adding test TLDs list to the package.
- switch back to pypi file.
* Sun Dec 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Switch to github tarball because of missing test files.
* Sun Dec 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.11.8:
  - Minor fixes in setup.py.
- update to version 0.11.7
  - There have been no code changes since 0.11.2. The only change is that
  support for Python 2.7 and 3.5 has been added.
  - Added support for Python 2.7.
- update to version 0.11.6:
  - Targeted releases for all supported Python versions.
- update to version 0.11.5:
  - Targeted releases for all supported Python versions.
- update to version 0.11.4:
  - Changed order of the releases (Python 3.6 and up come first, then Python 3.5).
  - Make all distributions except Python 3.5 universal.
- update to version 0.11.3:
  - Added missing resources to the Python 3.5 release.
- update to version 0.11.2:
  - Bring back Python 3.5 support.
- update to version 0.11.1:
  - Minor speed ups.
  - More on adding typing.
- update to version 0.11:
  - Since introduction of parser classes, usage of
  ``NAMES_SOURCE_URL`` and ``NAMES_LOCAL_PATH`` of the ``tld.conf``
  module is deprecated. Also, ``tld_names_local_path``
  and ``tld_names_source_url`` arguments are deprecated as well.
  If you want to customise things, implement your own parser (inherit from
  ``BaseTLDSourceParser``).
  - Drop support for Python versions prior to 3.6.
  - Clean-up dependencies.
  - Introduce parsers.
  - Drop ``tld_names_source_url`` and ``tld_names_local_path`` introduced
  in the previous release.
  - Minor speed-ups (including tests).
- update to version 0.10:
  - This is the last release to support Python 2.
  - Make it possible to provide a custom path to the TLD names file.
  - Make it possible to free up some resources occupied due to loading custom
  tld names by calling the ``reset_tld_names`` function
  with ``tld_names_local_path`` parameter.
* Tue Nov 26 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.9.8:
  - Fix for occasional issue when some domains are not correctly recognised.
- update to version 0.9.7:
  - Handling urls that are only a TLD.
  - Accepts already splitted URLs.
  - Tested against Python 3.8.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.6:
  * Fix for update-tld-names returns a non-zero exit code on success
  * Minor tests improvements.
* Sat Sep 14 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.9.5:
  - Tests improvements.
- update to version 0.9.4:
  - Optimisations in setup.py, tests and console scripts.
  - Skip testing the update-tld-names functionality if no internet is available.
- add skip_internet_tests.patch
- remove remove-download-test.patch
* Sun Apr  7 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.9.3:
  - Added `is_tld` function.
  - Docs updated.
  - Upgrade test suite.
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase.
* Tue Jan 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 0.9.2:
  * Fix an issue causing certain punycode TLDs to be deemed invalid.
  * Tested against Python 3.7.
  * Added tests for commands.
  * Dropped Python 2.6 support.
  * TLD source updated to the latest version.
- Update and extend remove-download-test.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul  9 2018 sebix+novell.com@sebix.at
- remove fix-setup-test.patch, merged upstream
- update to version 0.9.1:
  * Correctly handling nested TLDs.
- update to version 0.9:
  * This release contains backward incompatible changes. You should update your code.
  * The active_only option has been removed from get_tld, get_fld and parse_url functions. Update your code accordingly.
  * Removed active_only option from get_tld, get_fld and parse_url functions.
  * Correctly handling exceptions (!) in the original TLD list.
  * Fixes in documentation.
  * Added parse_tld function.
  * Fixes the python setup.py test command.
* Fri Jul  6 2018 sebix+novell.com@sebix.at
- add remove-download-test.patch to remove download test requiring internet
- add fix-setup-test.patch to fix setup.py test_suite specifier
- update to version 0.8:
  - This release contains backward incompatible changes. You should update
  your code.
  Old `get_tld` functionality remain is moved to `get_fld` (first-level
  domain definition). The `as_object` argument (False by default) has been
  deprecated for `get_fld`.
  Have a look at the packages' documentation and changelog for details and examples.
  - Move to a Trie to match TLDs. This brings a speed up of 15-20%%.
  - It's now possible to search in public, private or all suffixes (old
  behaviour). Use `search_public` and `search_private` arguments accordingly.
  By default (to support old behavior), both are set to True.
  - Correct TLD definitions.
  - Domains like `*****.xn--fiqs8s` are now recognized as well.
  - Due to usage of `urlsplit` instead of `urlparse`, the initial list of TLDs
  is assembled quicker (a speed-up of 15-20%%).
  - Docs/ directory is included in source distribution tarball.
* Sat Apr  7 2018 sebix+novell.com@sebix.at
- update to version 0.7.10:
  * more documentation files included
  * included license file
  * update tld data
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- initial package for version 0.7.9
